==> haskell-lifted-base-0.2.3.11-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-lifted-base.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lifted-base
version: 0.2.3.11
id: lifted-base-0.2.3.11-D5Xv69EKf6L9rLXYpe3sxE
key: lifted-base-0.2.3.11-D5Xv69EKf6L9rLXYpe3sxE
license: BSD3
copyright: (c) 2011-2012 Bas van Dijk, Anders Kaseorg
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
homepage: https://github.com/basvandijk/lifted-base
synopsis: lifted IO operations from the base library
description:
    @lifted-base@ exports IO operations from the base library lifted to
    any instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.
    .
    Note that not all modules from @base@ are converted yet. If
    you need a lifted version of a function from @base@, just
    ask me to add it or send me a patch.
    .
    The package includes a copy of the @monad-peel@ testsuite written
    by Anders Kaseorg The tests can be performed using @cabal test@.
category: Control
author: Bas van Dijk, Anders Kaseorg
exposed: True
exposed-modules:
    Control.Exception.Lifted Control.Concurrent.MVar.Lifted
    Control.Concurrent.Chan.Lifted Control.Concurrent.QSem.Lifted
    Control.Concurrent.QSemN.Lifted Control.Concurrent.Lifted
    Data.IORef.Lifted Foreign.Marshal.Utils.Lifted
    System.Timeout.Lifted
abi: 49ef3a5746e1e01fc295f8cd5ef0635f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/lifted-base-0.2.3.11
library-dirs: /usr/lib/ghc-8.0.1/site-local/lifted-base-0.2.3.11
data-dir: /usr/share/arm-linux-ghc-8.0.1/lifted-base-0.2.3.11
hs-libraries: HSlifted-base-0.2.3.11-D5Xv69EKf6L9rLXYpe3sxE
includes:
    inlinable.h
depends:
    base-4.9.0.0 monad-control-1.0.2.0-4qPEnRApnc4gRDkIzJcM5
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
haddock-interfaces: /usr/share/doc/haskell-lifted-base/html/lifted-base.haddock
haddock-html: /usr/share/doc/haskell-lifted-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lifted-base-0.2.3.11-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-lifted-base.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lifted-base
version: 0.2.3.11
id: lifted-base-0.2.3.11-797F0GSRM4GHiCBSQ3AJmQ
key: lifted-base-0.2.3.11-797F0GSRM4GHiCBSQ3AJmQ
license: BSD3
copyright: (c) 2011-2012 Bas van Dijk, Anders Kaseorg
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
homepage: https://github.com/basvandijk/lifted-base
synopsis: lifted IO operations from the base library
description:
    @lifted-base@ exports IO operations from the base library lifted to
    any instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.
    .
    Note that not all modules from @base@ are converted yet. If
    you need a lifted version of a function from @base@, just
    ask me to add it or send me a patch.
    .
    The package includes a copy of the @monad-peel@ testsuite written
    by Anders Kaseorg The tests can be performed using @cabal test@.
category: Control
author: Bas van Dijk, Anders Kaseorg
exposed: True
exposed-modules:
    Control.Exception.Lifted Control.Concurrent.MVar.Lifted
    Control.Concurrent.Chan.Lifted Control.Concurrent.QSem.Lifted
    Control.Concurrent.QSemN.Lifted Control.Concurrent.Lifted
    Data.IORef.Lifted Foreign.Marshal.Utils.Lifted
    System.Timeout.Lifted
abi: 6f47d32775f89a52e0a451be410bd37a
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/lifted-base-0.2.3.11
library-dirs: /usr/lib/ghc-8.0.2/site-local/lifted-base-0.2.3.11
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/lifted-base-0.2.3.11
hs-libraries: HSlifted-base-0.2.3.11-797F0GSRM4GHiCBSQ3AJmQ
includes:
    inlinable.h
depends:
    base-4.9.1.0 monad-control-1.0.2.0-10S0ywqdsCPHnUTlxJLEct
    transformers-base-0.4.4-H3XecnBtTa65CX4xecxCVH
haddock-interfaces: /usr/share/doc/haskell-lifted-base/html/lifted-base.haddock
haddock-html: /usr/share/doc/haskell-lifted-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
